@@ -462,6 +462,12 @@ class AutoscalersClient(metaclass=AutoscalersClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.aggregated_list]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("project", request.project),)),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -556,6 +562,18 @@ class AutoscalersClient(metaclass=AutoscalersClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.delete]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("zone", request.zone),
+                    ("autoscaler", request.autoscaler),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -641,6 +659,18 @@ class AutoscalersClient(metaclass=AutoscalersClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.delete]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("zone", request.zone),
+                    ("autoscaler", request.autoscaler),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -761,6 +791,18 @@ class AutoscalersClient(metaclass=AutoscalersClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.get]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("zone", request.zone),
+                    ("autoscaler", request.autoscaler),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -847,6 +889,17 @@ class AutoscalersClient(metaclass=AutoscalersClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.insert]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("zone", request.zone),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -933,6 +986,17 @@ class AutoscalersClient(metaclass=AutoscalersClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.insert]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("zone", request.zone),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1039,6 +1103,17 @@ class AutoscalersClient(metaclass=AutoscalersClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.list]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("zone", request.zone),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1136,6 +1211,17 @@ class AutoscalersClient(metaclass=AutoscalersClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.patch]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("zone", request.zone),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1224,6 +1310,17 @@ class AutoscalersClient(metaclass=AutoscalersClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.patch]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("zone", request.zone),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1335,6 +1432,17 @@ class AutoscalersClient(metaclass=AutoscalersClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.update]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("zone", request.zone),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1421,6 +1529,17 @@ class AutoscalersClient(metaclass=AutoscalersClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.update]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("zone", request.zone),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
