@@ -464,6 +464,12 @@ class ForwardingRulesClient(metaclass=ForwardingRulesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.aggregated_list]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("project", request.project),)),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -562,6 +568,18 @@ class ForwardingRulesClient(metaclass=ForwardingRulesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.delete]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    ("forwarding_rule", request.forwarding_rule),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -651,6 +669,18 @@ class ForwardingRulesClient(metaclass=ForwardingRulesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.delete]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    ("forwarding_rule", request.forwarding_rule),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -775,6 +805,18 @@ class ForwardingRulesClient(metaclass=ForwardingRulesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.get]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    ("forwarding_rule", request.forwarding_rule),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -864,6 +906,17 @@ class ForwardingRulesClient(metaclass=ForwardingRulesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.insert]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -953,6 +1006,17 @@ class ForwardingRulesClient(metaclass=ForwardingRulesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.insert]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1061,6 +1125,17 @@ class ForwardingRulesClient(metaclass=ForwardingRulesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.list]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1172,6 +1247,18 @@ class ForwardingRulesClient(metaclass=ForwardingRulesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.patch]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    ("forwarding_rule", request.forwarding_rule),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1274,6 +1361,18 @@ class ForwardingRulesClient(metaclass=ForwardingRulesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.patch]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    ("forwarding_rule", request.forwarding_rule),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1400,6 +1499,18 @@ class ForwardingRulesClient(metaclass=ForwardingRulesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.set_labels]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    ("resource", request.resource),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1501,6 +1612,18 @@ class ForwardingRulesClient(metaclass=ForwardingRulesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.set_labels]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    ("resource", request.resource),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1626,6 +1749,18 @@ class ForwardingRulesClient(metaclass=ForwardingRulesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.set_target]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    ("forwarding_rule", request.forwarding_rule),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1726,6 +1861,18 @@ class ForwardingRulesClient(metaclass=ForwardingRulesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.set_target]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    ("forwarding_rule", request.forwarding_rule),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
