@@ -292,8 +292,6 @@ class GlobalForwardingRulesRestTransport(GlobalForwardingRulesTransport):
     It sends JSON representations of protocol buffers over HTTP/1.1
     """
 
-    _STUBS: Dict[str, GlobalForwardingRulesRestStub] = {}
-
     def __init__(
         self,
         *,
@@ -1120,43 +1118,25 @@ class GlobalForwardingRulesRestTransport(GlobalForwardingRulesTransport):
     def delete(
         self,
     ) -> Callable[[compute.DeleteGlobalForwardingRuleRequest], compute.Operation]:
-        stub = self._STUBS.get("delete")
-        if not stub:
-            stub = self._STUBS["delete"] = self._Delete(
-                self._session, self._host, self._interceptor
-            )
-
         # The return type is fine, but mypy isn't sophisticated enough to determine what's going on here.
         # In C++ this would require a dynamic_cast
-        return stub  # type: ignore
+        return self._Delete(self._session, self._host, self._interceptor)  # type: ignore
 
     @property
     def get(
         self,
     ) -> Callable[[compute.GetGlobalForwardingRuleRequest], compute.ForwardingRule]:
-        stub = self._STUBS.get("get")
-        if not stub:
-            stub = self._STUBS["get"] = self._Get(
-                self._session, self._host, self._interceptor
-            )
-
         # The return type is fine, but mypy isn't sophisticated enough to determine what's going on here.
         # In C++ this would require a dynamic_cast
-        return stub  # type: ignore
+        return self._Get(self._session, self._host, self._interceptor)  # type: ignore
 
     @property
     def insert(
         self,
     ) -> Callable[[compute.InsertGlobalForwardingRuleRequest], compute.Operation]:
-        stub = self._STUBS.get("insert")
-        if not stub:
-            stub = self._STUBS["insert"] = self._Insert(
-                self._session, self._host, self._interceptor
-            )
-
         # The return type is fine, but mypy isn't sophisticated enough to determine what's going on here.
         # In C++ this would require a dynamic_cast
-        return stub  # type: ignore
+        return self._Insert(self._session, self._host, self._interceptor)  # type: ignore
 
     @property
     def list(
@@ -1164,57 +1144,33 @@ class GlobalForwardingRulesRestTransport(GlobalForwardingRulesTransport):
     ) -> Callable[
         [compute.ListGlobalForwardingRulesRequest], compute.ForwardingRuleList
     ]:
-        stub = self._STUBS.get("list")
-        if not stub:
-            stub = self._STUBS["list"] = self._List(
-                self._session, self._host, self._interceptor
-            )
-
         # The return type is fine, but mypy isn't sophisticated enough to determine what's going on here.
         # In C++ this would require a dynamic_cast
-        return stub  # type: ignore
+        return self._List(self._session, self._host, self._interceptor)  # type: ignore
 
     @property
     def patch(
         self,
     ) -> Callable[[compute.PatchGlobalForwardingRuleRequest], compute.Operation]:
-        stub = self._STUBS.get("patch")
-        if not stub:
-            stub = self._STUBS["patch"] = self._Patch(
-                self._session, self._host, self._interceptor
-            )
-
         # The return type is fine, but mypy isn't sophisticated enough to determine what's going on here.
         # In C++ this would require a dynamic_cast
-        return stub  # type: ignore
+        return self._Patch(self._session, self._host, self._interceptor)  # type: ignore
 
     @property
     def set_labels(
         self,
     ) -> Callable[[compute.SetLabelsGlobalForwardingRuleRequest], compute.Operation]:
-        stub = self._STUBS.get("set_labels")
-        if not stub:
-            stub = self._STUBS["set_labels"] = self._SetLabels(
-                self._session, self._host, self._interceptor
-            )
-
         # The return type is fine, but mypy isn't sophisticated enough to determine what's going on here.
         # In C++ this would require a dynamic_cast
-        return stub  # type: ignore
+        return self._SetLabels(self._session, self._host, self._interceptor)  # type: ignore
 
     @property
     def set_target(
         self,
     ) -> Callable[[compute.SetTargetGlobalForwardingRuleRequest], compute.Operation]:
-        stub = self._STUBS.get("set_target")
-        if not stub:
-            stub = self._STUBS["set_target"] = self._SetTarget(
-                self._session, self._host, self._interceptor
-            )
-
         # The return type is fine, but mypy isn't sophisticated enough to determine what's going on here.
         # In C++ this would require a dynamic_cast
-        return stub  # type: ignore
+        return self._SetTarget(self._session, self._host, self._interceptor)  # type: ignore
 
     @property
     def kind(self) -> str:
