@@ -461,6 +461,12 @@ class GlobalOperationsClient(metaclass=GlobalOperationsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.aggregated_list]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("project", request.project),)),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -550,6 +556,17 @@ class GlobalOperationsClient(metaclass=GlobalOperationsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.delete]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("operation", request.operation),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -642,6 +659,17 @@ class GlobalOperationsClient(metaclass=GlobalOperationsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.get]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("operation", request.operation),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -715,6 +743,12 @@ class GlobalOperationsClient(metaclass=GlobalOperationsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.list]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("project", request.project),)),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -828,6 +862,17 @@ class GlobalOperationsClient(metaclass=GlobalOperationsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.wait]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("operation", request.operation),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
