@@ -250,8 +250,6 @@ class GlobalPublicDelegatedPrefixesRestTransport(
     It sends JSON representations of protocol buffers over HTTP/1.1
     """
 
-    _STUBS: Dict[str, GlobalPublicDelegatedPrefixesRestStub] = {}
-
     def __init__(
         self,
         *,
@@ -859,15 +857,9 @@ class GlobalPublicDelegatedPrefixesRestTransport(
     ) -> Callable[
         [compute.DeleteGlobalPublicDelegatedPrefixeRequest], compute.Operation
     ]:
-        stub = self._STUBS.get("delete")
-        if not stub:
-            stub = self._STUBS["delete"] = self._Delete(
-                self._session, self._host, self._interceptor
-            )
-
         # The return type is fine, but mypy isn't sophisticated enough to determine what's going on here.
         # In C++ this would require a dynamic_cast
-        return stub  # type: ignore
+        return self._Delete(self._session, self._host, self._interceptor)  # type: ignore
 
     @property
     def get(
@@ -875,15 +867,9 @@ class GlobalPublicDelegatedPrefixesRestTransport(
     ) -> Callable[
         [compute.GetGlobalPublicDelegatedPrefixeRequest], compute.PublicDelegatedPrefix
     ]:
-        stub = self._STUBS.get("get")
-        if not stub:
-            stub = self._STUBS["get"] = self._Get(
-                self._session, self._host, self._interceptor
-            )
-
         # The return type is fine, but mypy isn't sophisticated enough to determine what's going on here.
         # In C++ this would require a dynamic_cast
-        return stub  # type: ignore
+        return self._Get(self._session, self._host, self._interceptor)  # type: ignore
 
     @property
     def insert(
@@ -891,15 +877,9 @@ class GlobalPublicDelegatedPrefixesRestTransport(
     ) -> Callable[
         [compute.InsertGlobalPublicDelegatedPrefixeRequest], compute.Operation
     ]:
-        stub = self._STUBS.get("insert")
-        if not stub:
-            stub = self._STUBS["insert"] = self._Insert(
-                self._session, self._host, self._interceptor
-            )
-
         # The return type is fine, but mypy isn't sophisticated enough to determine what's going on here.
         # In C++ this would require a dynamic_cast
-        return stub  # type: ignore
+        return self._Insert(self._session, self._host, self._interceptor)  # type: ignore
 
     @property
     def list(
@@ -908,15 +888,9 @@ class GlobalPublicDelegatedPrefixesRestTransport(
         [compute.ListGlobalPublicDelegatedPrefixesRequest],
         compute.PublicDelegatedPrefixList,
     ]:
-        stub = self._STUBS.get("list")
-        if not stub:
-            stub = self._STUBS["list"] = self._List(
-                self._session, self._host, self._interceptor
-            )
-
         # The return type is fine, but mypy isn't sophisticated enough to determine what's going on here.
         # In C++ this would require a dynamic_cast
-        return stub  # type: ignore
+        return self._List(self._session, self._host, self._interceptor)  # type: ignore
 
     @property
     def patch(
@@ -924,15 +898,9 @@ class GlobalPublicDelegatedPrefixesRestTransport(
     ) -> Callable[
         [compute.PatchGlobalPublicDelegatedPrefixeRequest], compute.Operation
     ]:
-        stub = self._STUBS.get("patch")
-        if not stub:
-            stub = self._STUBS["patch"] = self._Patch(
-                self._session, self._host, self._interceptor
-            )
-
         # The return type is fine, but mypy isn't sophisticated enough to determine what's going on here.
         # In C++ this would require a dynamic_cast
-        return stub  # type: ignore
+        return self._Patch(self._session, self._host, self._interceptor)  # type: ignore
 
     @property
     def kind(self) -> str:
