@@ -479,6 +479,18 @@ class ImageFamilyViewsClient(metaclass=ImageFamilyViewsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.get]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("zone", request.zone),
+                    ("family", request.family),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
