@@ -468,6 +468,17 @@ class ImagesClient(metaclass=ImagesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.delete]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("image", request.image),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -544,6 +555,17 @@ class ImagesClient(metaclass=ImagesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.delete]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("image", request.image),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -655,6 +677,17 @@ class ImagesClient(metaclass=ImagesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.deprecate]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("image", request.image),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -742,6 +775,17 @@ class ImagesClient(metaclass=ImagesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.deprecate]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("image", request.image),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -845,6 +889,17 @@ class ImagesClient(metaclass=ImagesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.get]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("image", request.image),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -927,6 +982,17 @@ class ImagesClient(metaclass=ImagesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.get_from_family]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("family", request.family),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1045,6 +1111,17 @@ class ImagesClient(metaclass=ImagesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.get_iam_policy]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("resource", request.resource),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1122,6 +1199,12 @@ class ImagesClient(metaclass=ImagesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.insert]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("project", request.project),)),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1199,6 +1282,12 @@ class ImagesClient(metaclass=ImagesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.insert]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("project", request.project),)),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1300,6 +1389,12 @@ class ImagesClient(metaclass=ImagesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.list]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("project", request.project),)),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1395,6 +1490,17 @@ class ImagesClient(metaclass=ImagesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.patch]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("image", request.image),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1481,6 +1587,17 @@ class ImagesClient(metaclass=ImagesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.patch]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("image", request.image),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1635,6 +1752,17 @@ class ImagesClient(metaclass=ImagesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.set_iam_policy]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("resource", request.resource),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1727,6 +1855,17 @@ class ImagesClient(metaclass=ImagesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.set_labels]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("resource", request.resource),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1819,6 +1958,17 @@ class ImagesClient(metaclass=ImagesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.set_labels]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("resource", request.resource),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1933,6 +2083,17 @@ class ImagesClient(metaclass=ImagesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.test_iam_permissions]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("resource", request.resource),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
