@@ -503,6 +503,18 @@ class InstanceGroupsClient(metaclass=InstanceGroupsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.add_instances]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("zone", request.zone),
+                    ("instance_group", request.instance_group),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -612,6 +624,18 @@ class InstanceGroupsClient(metaclass=InstanceGroupsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.add_instances]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("zone", request.zone),
+                    ("instance_group", request.instance_group),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -708,6 +732,12 @@ class InstanceGroupsClient(metaclass=InstanceGroupsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.aggregated_list]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("project", request.project),)),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -809,6 +839,18 @@ class InstanceGroupsClient(metaclass=InstanceGroupsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.delete]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("zone", request.zone),
+                    ("instance_group", request.instance_group),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -901,6 +943,18 @@ class InstanceGroupsClient(metaclass=InstanceGroupsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.delete]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("zone", request.zone),
+                    ("instance_group", request.instance_group),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1029,6 +1083,18 @@ class InstanceGroupsClient(metaclass=InstanceGroupsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.get]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("zone", request.zone),
+                    ("instance_group", request.instance_group),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1117,6 +1183,17 @@ class InstanceGroupsClient(metaclass=InstanceGroupsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.insert]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("zone", request.zone),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1205,6 +1282,17 @@ class InstanceGroupsClient(metaclass=InstanceGroupsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.insert]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("zone", request.zone),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1314,6 +1402,17 @@ class InstanceGroupsClient(metaclass=InstanceGroupsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.list]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("zone", request.zone),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1432,6 +1531,18 @@ class InstanceGroupsClient(metaclass=InstanceGroupsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.list_instances]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("zone", request.zone),
+                    ("instance_group", request.instance_group),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1552,6 +1663,18 @@ class InstanceGroupsClient(metaclass=InstanceGroupsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.remove_instances]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("zone", request.zone),
+                    ("instance_group", request.instance_group),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1663,6 +1786,18 @@ class InstanceGroupsClient(metaclass=InstanceGroupsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.remove_instances]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("zone", request.zone),
+                    ("instance_group", request.instance_group),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1795,6 +1930,18 @@ class InstanceGroupsClient(metaclass=InstanceGroupsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.set_named_ports]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("zone", request.zone),
+                    ("instance_group", request.instance_group),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1902,6 +2049,18 @@ class InstanceGroupsClient(metaclass=InstanceGroupsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.set_named_ports]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("zone", request.zone),
+                    ("instance_group", request.instance_group),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
