@@ -469,6 +469,12 @@ class InterconnectAttachmentsClient(metaclass=InterconnectAttachmentsClientMeta)
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.aggregated_list]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("project", request.project),)),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -565,6 +571,18 @@ class InterconnectAttachmentsClient(metaclass=InterconnectAttachmentsClientMeta)
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.delete]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    ("interconnect_attachment", request.interconnect_attachment),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -652,6 +670,18 @@ class InterconnectAttachmentsClient(metaclass=InterconnectAttachmentsClientMeta)
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.delete]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    ("interconnect_attachment", request.interconnect_attachment),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -770,6 +800,18 @@ class InterconnectAttachmentsClient(metaclass=InterconnectAttachmentsClientMeta)
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.get]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    ("interconnect_attachment", request.interconnect_attachment),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -858,6 +900,17 @@ class InterconnectAttachmentsClient(metaclass=InterconnectAttachmentsClientMeta)
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.insert]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -946,6 +999,17 @@ class InterconnectAttachmentsClient(metaclass=InterconnectAttachmentsClientMeta)
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.insert]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1052,6 +1116,17 @@ class InterconnectAttachmentsClient(metaclass=InterconnectAttachmentsClientMeta)
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.list]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1165,6 +1240,18 @@ class InterconnectAttachmentsClient(metaclass=InterconnectAttachmentsClientMeta)
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.patch]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    ("interconnect_attachment", request.interconnect_attachment),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1269,6 +1356,18 @@ class InterconnectAttachmentsClient(metaclass=InterconnectAttachmentsClientMeta)
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.patch]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    ("interconnect_attachment", request.interconnect_attachment),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
