@@ -477,6 +477,17 @@ class InterconnectLocationsClient(metaclass=InterconnectLocationsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.get]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("interconnect_location", request.interconnect_location),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -550,6 +561,12 @@ class InterconnectLocationsClient(metaclass=InterconnectLocationsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.list]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("project", request.project),)),
+        )
+
         # Send the request.
         response = rpc(
             request,
