@@ -154,8 +154,6 @@ class InterconnectLocationsRestTransport(InterconnectLocationsTransport):
     It sends JSON representations of protocol buffers over HTTP/1.1
     """
 
-    _STUBS: Dict[str, InterconnectLocationsRestStub] = {}
-
     def __init__(
         self,
         *,
@@ -424,15 +422,9 @@ class InterconnectLocationsRestTransport(InterconnectLocationsTransport):
     ) -> Callable[
         [compute.GetInterconnectLocationRequest], compute.InterconnectLocation
     ]:
-        stub = self._STUBS.get("get")
-        if not stub:
-            stub = self._STUBS["get"] = self._Get(
-                self._session, self._host, self._interceptor
-            )
-
         # The return type is fine, but mypy isn't sophisticated enough to determine what's going on here.
         # In C++ this would require a dynamic_cast
-        return stub  # type: ignore
+        return self._Get(self._session, self._host, self._interceptor)  # type: ignore
 
     @property
     def list(
@@ -440,15 +432,9 @@ class InterconnectLocationsRestTransport(InterconnectLocationsTransport):
     ) -> Callable[
         [compute.ListInterconnectLocationsRequest], compute.InterconnectLocationList
     ]:
-        stub = self._STUBS.get("list")
-        if not stub:
-            stub = self._STUBS["list"] = self._List(
-                self._session, self._host, self._interceptor
-            )
-
         # The return type is fine, but mypy isn't sophisticated enough to determine what's going on here.
         # In C++ this would require a dynamic_cast
-        return stub  # type: ignore
+        return self._List(self._session, self._host, self._interceptor)  # type: ignore
 
     @property
     def kind(self) -> str:
