@@ -469,6 +469,17 @@ class InterconnectsClient(metaclass=InterconnectsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.delete]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("interconnect", request.interconnect),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -546,6 +557,17 @@ class InterconnectsClient(metaclass=InterconnectsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.delete]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("interconnect", request.interconnect),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -652,6 +674,17 @@ class InterconnectsClient(metaclass=InterconnectsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.get]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("interconnect", request.interconnect),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -732,6 +765,17 @@ class InterconnectsClient(metaclass=InterconnectsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.get_diagnostics]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("interconnect", request.interconnect),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -810,6 +854,12 @@ class InterconnectsClient(metaclass=InterconnectsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.insert]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("project", request.project),)),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -888,6 +938,12 @@ class InterconnectsClient(metaclass=InterconnectsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.insert]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("project", request.project),)),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -985,6 +1041,12 @@ class InterconnectsClient(metaclass=InterconnectsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.list]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("project", request.project),)),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1082,6 +1144,17 @@ class InterconnectsClient(metaclass=InterconnectsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.patch]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("interconnect", request.interconnect),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1170,6 +1243,17 @@ class InterconnectsClient(metaclass=InterconnectsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.patch]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("interconnect", request.interconnect),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
