@@ -473,6 +473,17 @@ class LicenseCodesClient(metaclass=LicenseCodesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.get]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("license_code", request.license_code),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -564,6 +575,17 @@ class LicenseCodesClient(metaclass=LicenseCodesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.test_iam_permissions]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("resource", request.resource),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
