@@ -473,6 +473,12 @@ class NetworkEdgeSecurityServicesClient(
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.aggregated_list]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("project", request.project),)),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -571,6 +577,21 @@ class NetworkEdgeSecurityServicesClient(
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.delete]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    (
+                        "network_edge_security_service",
+                        request.network_edge_security_service,
+                    ),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -660,6 +681,21 @@ class NetworkEdgeSecurityServicesClient(
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.delete]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    (
+                        "network_edge_security_service",
+                        request.network_edge_security_service,
+                    ),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -774,6 +810,21 @@ class NetworkEdgeSecurityServicesClient(
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.get]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    (
+                        "network_edge_security_service",
+                        request.network_edge_security_service,
+                    ),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -866,6 +917,17 @@ class NetworkEdgeSecurityServicesClient(
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.insert]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -958,6 +1020,17 @@ class NetworkEdgeSecurityServicesClient(
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.insert]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1090,6 +1163,21 @@ class NetworkEdgeSecurityServicesClient(
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.patch]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    (
+                        "network_edge_security_service",
+                        request.network_edge_security_service,
+                    ),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1197,6 +1285,21 @@ class NetworkEdgeSecurityServicesClient(
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.patch]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    (
+                        "network_edge_security_service",
+                        request.network_edge_security_service,
+                    ),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
