@@ -484,6 +484,18 @@ class RegionBackendServicesClient(metaclass=RegionBackendServicesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.delete]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    ("backend_service", request.backend_service),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -574,6 +586,18 @@ class RegionBackendServicesClient(metaclass=RegionBackendServicesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.delete]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    ("backend_service", request.backend_service),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -702,6 +726,18 @@ class RegionBackendServicesClient(metaclass=RegionBackendServicesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.get]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    ("backend_service", request.backend_service),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -802,6 +838,18 @@ class RegionBackendServicesClient(metaclass=RegionBackendServicesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.get_health]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    ("backend_service", request.backend_service),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -892,6 +940,17 @@ class RegionBackendServicesClient(metaclass=RegionBackendServicesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.insert]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -982,6 +1041,17 @@ class RegionBackendServicesClient(metaclass=RegionBackendServicesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.insert]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1091,6 +1161,17 @@ class RegionBackendServicesClient(metaclass=RegionBackendServicesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.list]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1203,6 +1284,18 @@ class RegionBackendServicesClient(metaclass=RegionBackendServicesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.patch]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    ("backend_service", request.backend_service),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1306,6 +1399,18 @@ class RegionBackendServicesClient(metaclass=RegionBackendServicesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.patch]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    ("backend_service", request.backend_service),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1432,6 +1537,18 @@ class RegionBackendServicesClient(metaclass=RegionBackendServicesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.update]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    ("backend_service", request.backend_service),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1533,6 +1650,18 @@ class RegionBackendServicesClient(metaclass=RegionBackendServicesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.update]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    ("backend_service", request.backend_service),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
