@@ -484,6 +484,18 @@ class RegionHealthCheckServicesClient(metaclass=RegionHealthCheckServicesClientM
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.delete]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    ("health_check_service", request.health_check_service),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -574,6 +586,18 @@ class RegionHealthCheckServicesClient(metaclass=RegionHealthCheckServicesClientM
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.delete]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    ("health_check_service", request.health_check_service),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -690,6 +714,18 @@ class RegionHealthCheckServicesClient(metaclass=RegionHealthCheckServicesClientM
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.get]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    ("health_check_service", request.health_check_service),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -779,6 +815,17 @@ class RegionHealthCheckServicesClient(metaclass=RegionHealthCheckServicesClientM
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.insert]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -868,6 +915,17 @@ class RegionHealthCheckServicesClient(metaclass=RegionHealthCheckServicesClientM
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.insert]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -975,6 +1033,17 @@ class RegionHealthCheckServicesClient(metaclass=RegionHealthCheckServicesClientM
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.list]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1087,6 +1156,18 @@ class RegionHealthCheckServicesClient(metaclass=RegionHealthCheckServicesClientM
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.patch]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    ("health_check_service", request.health_check_service),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1190,6 +1271,18 @@ class RegionHealthCheckServicesClient(metaclass=RegionHealthCheckServicesClientM
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.patch]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    ("health_check_service", request.health_check_service),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
