@@ -483,6 +483,18 @@ class RegionHealthChecksClient(metaclass=RegionHealthChecksClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.delete]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    ("health_check", request.health_check),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -572,6 +584,18 @@ class RegionHealthChecksClient(metaclass=RegionHealthChecksClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.delete]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    ("health_check", request.health_check),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -705,6 +729,18 @@ class RegionHealthChecksClient(metaclass=RegionHealthChecksClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.get]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    ("health_check", request.health_check),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -793,6 +829,17 @@ class RegionHealthChecksClient(metaclass=RegionHealthChecksClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.insert]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -881,6 +928,17 @@ class RegionHealthChecksClient(metaclass=RegionHealthChecksClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.insert]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -989,6 +1047,17 @@ class RegionHealthChecksClient(metaclass=RegionHealthChecksClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.list]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1100,6 +1169,18 @@ class RegionHealthChecksClient(metaclass=RegionHealthChecksClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.patch]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    ("health_check", request.health_check),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1202,6 +1283,18 @@ class RegionHealthChecksClient(metaclass=RegionHealthChecksClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.patch]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    ("health_check", request.health_check),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1327,6 +1420,18 @@ class RegionHealthChecksClient(metaclass=RegionHealthChecksClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.update]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    ("health_check", request.health_check),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1427,6 +1532,18 @@ class RegionHealthChecksClient(metaclass=RegionHealthChecksClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.update]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    ("health_check", request.health_check),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
