@@ -495,6 +495,18 @@ class RegionInstanceGroupsClient(metaclass=RegionInstanceGroupsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.get]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    ("instance_group", request.instance_group),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -578,6 +590,17 @@ class RegionInstanceGroupsClient(metaclass=RegionInstanceGroupsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.list]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -698,6 +721,18 @@ class RegionInstanceGroupsClient(metaclass=RegionInstanceGroupsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.list_instances]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    ("instance_group", request.instance_group),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -814,6 +849,18 @@ class RegionInstanceGroupsClient(metaclass=RegionInstanceGroupsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.set_named_ports]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    ("instance_group", request.instance_group),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -921,6 +968,18 @@ class RegionInstanceGroupsClient(metaclass=RegionInstanceGroupsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.set_named_ports]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    ("instance_group", request.instance_group),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
