@@ -214,8 +214,6 @@ class RegionInstanceGroupsRestTransport(RegionInstanceGroupsTransport):
     It sends JSON representations of protocol buffers over HTTP/1.1
     """
 
-    _STUBS: Dict[str, RegionInstanceGroupsRestStub] = {}
-
     def __init__(
         self,
         *,
@@ -705,15 +703,9 @@ class RegionInstanceGroupsRestTransport(RegionInstanceGroupsTransport):
     def get(
         self,
     ) -> Callable[[compute.GetRegionInstanceGroupRequest], compute.InstanceGroup]:
-        stub = self._STUBS.get("get")
-        if not stub:
-            stub = self._STUBS["get"] = self._Get(
-                self._session, self._host, self._interceptor
-            )
-
         # The return type is fine, but mypy isn't sophisticated enough to determine what's going on here.
         # In C++ this would require a dynamic_cast
-        return stub  # type: ignore
+        return self._Get(self._session, self._host, self._interceptor)  # type: ignore
 
     @property
     def list(
@@ -721,15 +713,9 @@ class RegionInstanceGroupsRestTransport(RegionInstanceGroupsTransport):
     ) -> Callable[
         [compute.ListRegionInstanceGroupsRequest], compute.RegionInstanceGroupList
     ]:
-        stub = self._STUBS.get("list")
-        if not stub:
-            stub = self._STUBS["list"] = self._List(
-                self._session, self._host, self._interceptor
-            )
-
         # The return type is fine, but mypy isn't sophisticated enough to determine what's going on here.
         # In C++ this would require a dynamic_cast
-        return stub  # type: ignore
+        return self._List(self._session, self._host, self._interceptor)  # type: ignore
 
     @property
     def list_instances(
@@ -738,29 +724,17 @@ class RegionInstanceGroupsRestTransport(RegionInstanceGroupsTransport):
         [compute.ListInstancesRegionInstanceGroupsRequest],
         compute.RegionInstanceGroupsListInstances,
     ]:
-        stub = self._STUBS.get("list_instances")
-        if not stub:
-            stub = self._STUBS["list_instances"] = self._ListInstances(
-                self._session, self._host, self._interceptor
-            )
-
         # The return type is fine, but mypy isn't sophisticated enough to determine what's going on here.
         # In C++ this would require a dynamic_cast
-        return stub  # type: ignore
+        return self._ListInstances(self._session, self._host, self._interceptor)  # type: ignore
 
     @property
     def set_named_ports(
         self,
     ) -> Callable[[compute.SetNamedPortsRegionInstanceGroupRequest], compute.Operation]:
-        stub = self._STUBS.get("set_named_ports")
-        if not stub:
-            stub = self._STUBS["set_named_ports"] = self._SetNamedPorts(
-                self._session, self._host, self._interceptor
-            )
-
         # The return type is fine, but mypy isn't sophisticated enough to determine what's going on here.
         # In C++ this would require a dynamic_cast
-        return stub  # type: ignore
+        return self._SetNamedPorts(self._session, self._host, self._interceptor)  # type: ignore
 
     @property
     def kind(self) -> str:
