@@ -208,8 +208,6 @@ class RegionOperationsRestTransport(RegionOperationsTransport):
     It sends JSON representations of protocol buffers over HTTP/1.1
     """
 
-    _STUBS: Dict[str, RegionOperationsRestStub] = {}
-
     def __init__(
         self,
         *,
@@ -681,53 +679,29 @@ class RegionOperationsRestTransport(RegionOperationsTransport):
     ) -> Callable[
         [compute.DeleteRegionOperationRequest], compute.DeleteRegionOperationResponse
     ]:
-        stub = self._STUBS.get("delete")
-        if not stub:
-            stub = self._STUBS["delete"] = self._Delete(
-                self._session, self._host, self._interceptor
-            )
-
         # The return type is fine, but mypy isn't sophisticated enough to determine what's going on here.
         # In C++ this would require a dynamic_cast
-        return stub  # type: ignore
+        return self._Delete(self._session, self._host, self._interceptor)  # type: ignore
 
     @property
     def get(self) -> Callable[[compute.GetRegionOperationRequest], compute.Operation]:
-        stub = self._STUBS.get("get")
-        if not stub:
-            stub = self._STUBS["get"] = self._Get(
-                self._session, self._host, self._interceptor
-            )
-
         # The return type is fine, but mypy isn't sophisticated enough to determine what's going on here.
         # In C++ this would require a dynamic_cast
-        return stub  # type: ignore
+        return self._Get(self._session, self._host, self._interceptor)  # type: ignore
 
     @property
     def list(
         self,
     ) -> Callable[[compute.ListRegionOperationsRequest], compute.OperationList]:
-        stub = self._STUBS.get("list")
-        if not stub:
-            stub = self._STUBS["list"] = self._List(
-                self._session, self._host, self._interceptor
-            )
-
         # The return type is fine, but mypy isn't sophisticated enough to determine what's going on here.
         # In C++ this would require a dynamic_cast
-        return stub  # type: ignore
+        return self._List(self._session, self._host, self._interceptor)  # type: ignore
 
     @property
     def wait(self) -> Callable[[compute.WaitRegionOperationRequest], compute.Operation]:
-        stub = self._STUBS.get("wait")
-        if not stub:
-            stub = self._STUBS["wait"] = self._Wait(
-                self._session, self._host, self._interceptor
-            )
-
         # The return type is fine, but mypy isn't sophisticated enough to determine what's going on here.
         # In C++ this would require a dynamic_cast
-        return stub  # type: ignore
+        return self._Wait(self._session, self._host, self._interceptor)  # type: ignore
 
     @property
     def kind(self) -> str:
