@@ -463,6 +463,12 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.aggregated_list]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("project", request.project),)),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -557,6 +563,18 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.delete]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("zone", request.zone),
+                    ("reservation", request.reservation),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -642,6 +660,18 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.delete]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("zone", request.zone),
+                    ("reservation", request.reservation),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -757,6 +787,18 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.get]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("zone", request.zone),
+                    ("reservation", request.reservation),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -885,6 +927,18 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.get_iam_policy]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("zone", request.zone),
+                    ("resource", request.resource),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -971,6 +1025,17 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.insert]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("zone", request.zone),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1057,6 +1122,17 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.insert]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("zone", request.zone),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1161,6 +1237,17 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.list]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("zone", request.zone),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1269,6 +1356,18 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.resize]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("zone", request.zone),
+                    ("reservation", request.reservation),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1368,6 +1467,18 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.resize]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("zone", request.zone),
+                    ("reservation", request.reservation),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1533,6 +1644,18 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.set_iam_policy]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("zone", request.zone),
+                    ("resource", request.resource),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1633,6 +1756,18 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.test_iam_permissions]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("zone", request.zone),
+                    ("resource", request.resource),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1726,6 +1861,18 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.update]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("zone", request.zone),
+                    ("reservation", request.reservation),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1819,6 +1966,18 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.update]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("zone", request.zone),
+                    ("reservation", request.reservation),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
