@@ -483,6 +483,17 @@ class SecurityPoliciesClient(metaclass=SecurityPoliciesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.add_rule]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("security_policy", request.security_policy),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -572,6 +583,17 @@ class SecurityPoliciesClient(metaclass=SecurityPoliciesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.add_rule]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("security_policy", request.security_policy),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -669,6 +691,12 @@ class SecurityPoliciesClient(metaclass=SecurityPoliciesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.aggregated_list]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("project", request.project),)),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -757,6 +785,17 @@ class SecurityPoliciesClient(metaclass=SecurityPoliciesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.delete]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("security_policy", request.security_policy),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -836,6 +875,17 @@ class SecurityPoliciesClient(metaclass=SecurityPoliciesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.delete]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("security_policy", request.security_policy),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -942,6 +992,17 @@ class SecurityPoliciesClient(metaclass=SecurityPoliciesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.get]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("security_policy", request.security_policy),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1023,6 +1084,17 @@ class SecurityPoliciesClient(metaclass=SecurityPoliciesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.get_rule]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("security_policy", request.security_policy),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1101,6 +1173,12 @@ class SecurityPoliciesClient(metaclass=SecurityPoliciesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.insert]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("project", request.project),)),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1179,6 +1257,12 @@ class SecurityPoliciesClient(metaclass=SecurityPoliciesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.insert]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("project", request.project),)),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1274,6 +1358,12 @@ class SecurityPoliciesClient(metaclass=SecurityPoliciesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.list]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("project", request.project),)),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1359,6 +1449,12 @@ class SecurityPoliciesClient(metaclass=SecurityPoliciesClientMeta):
             self._transport.list_preconfigured_expression_sets
         ]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("project", request.project),)),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1449,6 +1545,17 @@ class SecurityPoliciesClient(metaclass=SecurityPoliciesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.patch]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("security_policy", request.security_policy),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1539,6 +1646,17 @@ class SecurityPoliciesClient(metaclass=SecurityPoliciesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.patch]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("security_policy", request.security_policy),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1652,6 +1770,17 @@ class SecurityPoliciesClient(metaclass=SecurityPoliciesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.patch_rule]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("security_policy", request.security_policy),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1741,6 +1870,17 @@ class SecurityPoliciesClient(metaclass=SecurityPoliciesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.patch_rule]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("security_policy", request.security_policy),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1844,6 +1984,17 @@ class SecurityPoliciesClient(metaclass=SecurityPoliciesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.remove_rule]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("security_policy", request.security_policy),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1923,6 +2074,17 @@ class SecurityPoliciesClient(metaclass=SecurityPoliciesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.remove_rule]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("security_policy", request.security_policy),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
