@@ -470,6 +470,12 @@ class ServiceAttachmentsClient(metaclass=ServiceAttachmentsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.aggregated_list]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("project", request.project),)),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -567,6 +573,18 @@ class ServiceAttachmentsClient(metaclass=ServiceAttachmentsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.delete]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    ("service_attachment", request.service_attachment),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -655,6 +673,18 @@ class ServiceAttachmentsClient(metaclass=ServiceAttachmentsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.delete]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    ("service_attachment", request.service_attachment),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -775,6 +805,18 @@ class ServiceAttachmentsClient(metaclass=ServiceAttachmentsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.get]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    ("service_attachment", request.service_attachment),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -903,6 +945,18 @@ class ServiceAttachmentsClient(metaclass=ServiceAttachmentsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.get_iam_policy]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    ("resource", request.resource),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -990,6 +1044,17 @@ class ServiceAttachmentsClient(metaclass=ServiceAttachmentsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.insert]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1077,6 +1142,17 @@ class ServiceAttachmentsClient(metaclass=ServiceAttachmentsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.insert]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1181,6 +1257,17 @@ class ServiceAttachmentsClient(metaclass=ServiceAttachmentsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.list]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1294,6 +1381,18 @@ class ServiceAttachmentsClient(metaclass=ServiceAttachmentsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.patch]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    ("service_attachment", request.service_attachment),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1398,6 +1497,18 @@ class ServiceAttachmentsClient(metaclass=ServiceAttachmentsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.patch]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    ("service_attachment", request.service_attachment),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1563,6 +1674,18 @@ class ServiceAttachmentsClient(metaclass=ServiceAttachmentsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.set_iam_policy]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    ("resource", request.resource),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1663,6 +1786,18 @@ class ServiceAttachmentsClient(metaclass=ServiceAttachmentsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.test_iam_permissions]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("region", request.region),
+                    ("resource", request.resource),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
