@@ -467,6 +467,12 @@ class SslCertificatesClient(metaclass=SslCertificatesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.aggregated_list]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("project", request.project),)),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -555,6 +561,17 @@ class SslCertificatesClient(metaclass=SslCertificatesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.delete]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("ssl_certificate", request.ssl_certificate),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -634,6 +651,17 @@ class SslCertificatesClient(metaclass=SslCertificatesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.delete]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("ssl_certificate", request.ssl_certificate),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -753,6 +781,17 @@ class SslCertificatesClient(metaclass=SslCertificatesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.get]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("ssl_certificate", request.ssl_certificate),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -831,6 +870,12 @@ class SslCertificatesClient(metaclass=SslCertificatesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.insert]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("project", request.project),)),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -909,6 +954,12 @@ class SslCertificatesClient(metaclass=SslCertificatesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.insert]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("project", request.project),)),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1006,6 +1057,12 @@ class SslCertificatesClient(metaclass=SslCertificatesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.list]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("project", request.project),)),
+        )
+
         # Send the request.
         response = rpc(
             request,
