@@ -474,6 +474,17 @@ class TargetGrpcProxiesClient(metaclass=TargetGrpcProxiesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.delete]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("target_grpc_proxy", request.target_grpc_proxy),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -554,6 +565,17 @@ class TargetGrpcProxiesClient(metaclass=TargetGrpcProxiesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.delete]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("target_grpc_proxy", request.target_grpc_proxy),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -663,6 +685,17 @@ class TargetGrpcProxiesClient(metaclass=TargetGrpcProxiesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.get]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("target_grpc_proxy", request.target_grpc_proxy),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -742,6 +775,12 @@ class TargetGrpcProxiesClient(metaclass=TargetGrpcProxiesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.insert]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("project", request.project),)),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -821,6 +860,12 @@ class TargetGrpcProxiesClient(metaclass=TargetGrpcProxiesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.insert]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("project", request.project),)),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -916,6 +961,12 @@ class TargetGrpcProxiesClient(metaclass=TargetGrpcProxiesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.list]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("project", request.project),)),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1017,6 +1068,17 @@ class TargetGrpcProxiesClient(metaclass=TargetGrpcProxiesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.patch]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("target_grpc_proxy", request.target_grpc_proxy),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1109,6 +1171,17 @@ class TargetGrpcProxiesClient(metaclass=TargetGrpcProxiesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.patch]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("target_grpc_proxy", request.target_grpc_proxy),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
