@@ -467,6 +467,12 @@ class TargetHttpProxiesClient(metaclass=TargetHttpProxiesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.aggregated_list]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("project", request.project),)),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -555,6 +561,17 @@ class TargetHttpProxiesClient(metaclass=TargetHttpProxiesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.delete]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("target_http_proxy", request.target_http_proxy),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -634,6 +651,17 @@ class TargetHttpProxiesClient(metaclass=TargetHttpProxiesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.delete]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("target_http_proxy", request.target_http_proxy),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -750,6 +778,17 @@ class TargetHttpProxiesClient(metaclass=TargetHttpProxiesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.get]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("target_http_proxy", request.target_http_proxy),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -828,6 +867,12 @@ class TargetHttpProxiesClient(metaclass=TargetHttpProxiesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.insert]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("project", request.project),)),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -906,6 +951,12 @@ class TargetHttpProxiesClient(metaclass=TargetHttpProxiesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.insert]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("project", request.project),)),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1002,6 +1053,12 @@ class TargetHttpProxiesClient(metaclass=TargetHttpProxiesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.list]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("project", request.project),)),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1103,6 +1160,17 @@ class TargetHttpProxiesClient(metaclass=TargetHttpProxiesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.patch]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("target_http_proxy", request.target_http_proxy),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1195,6 +1263,17 @@ class TargetHttpProxiesClient(metaclass=TargetHttpProxiesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.patch]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("target_http_proxy", request.target_http_proxy),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1308,6 +1387,17 @@ class TargetHttpProxiesClient(metaclass=TargetHttpProxiesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.set_url_map]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("target_http_proxy", request.target_http_proxy),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1397,6 +1487,17 @@ class TargetHttpProxiesClient(metaclass=TargetHttpProxiesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.set_url_map]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("target_http_proxy", request.target_http_proxy),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
