@@ -467,6 +467,12 @@ class TargetHttpsProxiesClient(metaclass=TargetHttpsProxiesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.aggregated_list]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("project", request.project),)),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -555,6 +561,17 @@ class TargetHttpsProxiesClient(metaclass=TargetHttpsProxiesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.delete]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("target_https_proxy", request.target_https_proxy),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -634,6 +651,17 @@ class TargetHttpsProxiesClient(metaclass=TargetHttpsProxiesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.delete]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("target_https_proxy", request.target_https_proxy),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -749,6 +777,17 @@ class TargetHttpsProxiesClient(metaclass=TargetHttpsProxiesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.get]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("target_https_proxy", request.target_https_proxy),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -827,6 +866,12 @@ class TargetHttpsProxiesClient(metaclass=TargetHttpsProxiesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.insert]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("project", request.project),)),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -905,6 +950,12 @@ class TargetHttpsProxiesClient(metaclass=TargetHttpsProxiesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.insert]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("project", request.project),)),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1002,6 +1053,12 @@ class TargetHttpsProxiesClient(metaclass=TargetHttpsProxiesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.list]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("project", request.project),)),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1103,6 +1160,17 @@ class TargetHttpsProxiesClient(metaclass=TargetHttpsProxiesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.patch]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("target_https_proxy", request.target_https_proxy),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1195,6 +1263,17 @@ class TargetHttpsProxiesClient(metaclass=TargetHttpsProxiesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.patch]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("target_https_proxy", request.target_https_proxy),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1315,6 +1394,17 @@ class TargetHttpsProxiesClient(metaclass=TargetHttpsProxiesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.set_quic_override]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("target_https_proxy", request.target_https_proxy),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1411,6 +1501,17 @@ class TargetHttpsProxiesClient(metaclass=TargetHttpsProxiesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.set_quic_override]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("target_https_proxy", request.target_https_proxy),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1530,6 +1631,17 @@ class TargetHttpsProxiesClient(metaclass=TargetHttpsProxiesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.set_ssl_certificates]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("target_https_proxy", request.target_https_proxy),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1625,6 +1737,17 @@ class TargetHttpsProxiesClient(metaclass=TargetHttpsProxiesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.set_ssl_certificates]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("target_https_proxy", request.target_https_proxy),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1744,6 +1867,17 @@ class TargetHttpsProxiesClient(metaclass=TargetHttpsProxiesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.set_ssl_policy]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("target_https_proxy", request.target_https_proxy),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1839,6 +1973,17 @@ class TargetHttpsProxiesClient(metaclass=TargetHttpsProxiesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.set_ssl_policy]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("target_https_proxy", request.target_https_proxy),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -1952,6 +2097,17 @@ class TargetHttpsProxiesClient(metaclass=TargetHttpsProxiesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.set_url_map]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("target_https_proxy", request.target_https_proxy),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -2041,6 +2197,17 @@ class TargetHttpsProxiesClient(metaclass=TargetHttpsProxiesClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.set_url_map]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("target_https_proxy", request.target_https_proxy),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
