@@ -328,8 +328,6 @@ class TargetSslProxiesRestTransport(TargetSslProxiesTransport):
     It sends JSON representations of protocol buffers over HTTP/1.1
     """
 
-    _STUBS: Dict[str, TargetSslProxiesRestStub] = {}
-
     def __init__(
         self,
         *,
@@ -1278,113 +1276,65 @@ class TargetSslProxiesRestTransport(TargetSslProxiesTransport):
     def delete(
         self,
     ) -> Callable[[compute.DeleteTargetSslProxyRequest], compute.Operation]:
-        stub = self._STUBS.get("delete")
-        if not stub:
-            stub = self._STUBS["delete"] = self._Delete(
-                self._session, self._host, self._interceptor
-            )
-
         # The return type is fine, but mypy isn't sophisticated enough to determine what's going on here.
         # In C++ this would require a dynamic_cast
-        return stub  # type: ignore
+        return self._Delete(self._session, self._host, self._interceptor)  # type: ignore
 
     @property
     def get(
         self,
     ) -> Callable[[compute.GetTargetSslProxyRequest], compute.TargetSslProxy]:
-        stub = self._STUBS.get("get")
-        if not stub:
-            stub = self._STUBS["get"] = self._Get(
-                self._session, self._host, self._interceptor
-            )
-
         # The return type is fine, but mypy isn't sophisticated enough to determine what's going on here.
         # In C++ this would require a dynamic_cast
-        return stub  # type: ignore
+        return self._Get(self._session, self._host, self._interceptor)  # type: ignore
 
     @property
     def insert(
         self,
     ) -> Callable[[compute.InsertTargetSslProxyRequest], compute.Operation]:
-        stub = self._STUBS.get("insert")
-        if not stub:
-            stub = self._STUBS["insert"] = self._Insert(
-                self._session, self._host, self._interceptor
-            )
-
         # The return type is fine, but mypy isn't sophisticated enough to determine what's going on here.
         # In C++ this would require a dynamic_cast
-        return stub  # type: ignore
+        return self._Insert(self._session, self._host, self._interceptor)  # type: ignore
 
     @property
     def list(
         self,
     ) -> Callable[[compute.ListTargetSslProxiesRequest], compute.TargetSslProxyList]:
-        stub = self._STUBS.get("list")
-        if not stub:
-            stub = self._STUBS["list"] = self._List(
-                self._session, self._host, self._interceptor
-            )
-
         # The return type is fine, but mypy isn't sophisticated enough to determine what's going on here.
         # In C++ this would require a dynamic_cast
-        return stub  # type: ignore
+        return self._List(self._session, self._host, self._interceptor)  # type: ignore
 
     @property
     def set_backend_service(
         self,
     ) -> Callable[[compute.SetBackendServiceTargetSslProxyRequest], compute.Operation]:
-        stub = self._STUBS.get("set_backend_service")
-        if not stub:
-            stub = self._STUBS["set_backend_service"] = self._SetBackendService(
-                self._session, self._host, self._interceptor
-            )
-
         # The return type is fine, but mypy isn't sophisticated enough to determine what's going on here.
         # In C++ this would require a dynamic_cast
-        return stub  # type: ignore
+        return self._SetBackendService(self._session, self._host, self._interceptor)  # type: ignore
 
     @property
     def set_proxy_header(
         self,
     ) -> Callable[[compute.SetProxyHeaderTargetSslProxyRequest], compute.Operation]:
-        stub = self._STUBS.get("set_proxy_header")
-        if not stub:
-            stub = self._STUBS["set_proxy_header"] = self._SetProxyHeader(
-                self._session, self._host, self._interceptor
-            )
-
         # The return type is fine, but mypy isn't sophisticated enough to determine what's going on here.
         # In C++ this would require a dynamic_cast
-        return stub  # type: ignore
+        return self._SetProxyHeader(self._session, self._host, self._interceptor)  # type: ignore
 
     @property
     def set_ssl_certificates(
         self,
     ) -> Callable[[compute.SetSslCertificatesTargetSslProxyRequest], compute.Operation]:
-        stub = self._STUBS.get("set_ssl_certificates")
-        if not stub:
-            stub = self._STUBS["set_ssl_certificates"] = self._SetSslCertificates(
-                self._session, self._host, self._interceptor
-            )
-
         # The return type is fine, but mypy isn't sophisticated enough to determine what's going on here.
         # In C++ this would require a dynamic_cast
-        return stub  # type: ignore
+        return self._SetSslCertificates(self._session, self._host, self._interceptor)  # type: ignore
 
     @property
     def set_ssl_policy(
         self,
     ) -> Callable[[compute.SetSslPolicyTargetSslProxyRequest], compute.Operation]:
-        stub = self._STUBS.get("set_ssl_policy")
-        if not stub:
-            stub = self._STUBS["set_ssl_policy"] = self._SetSslPolicy(
-                self._session, self._host, self._interceptor
-            )
-
         # The return type is fine, but mypy isn't sophisticated enough to determine what's going on here.
         # In C++ this would require a dynamic_cast
-        return stub  # type: ignore
+        return self._SetSslPolicy(self._session, self._host, self._interceptor)  # type: ignore
 
     @property
     def kind(self) -> str:
