@@ -480,6 +480,18 @@ class ZoneOperationsClient(metaclass=ZoneOperationsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.delete]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("zone", request.zone),
+                    ("operation", request.operation),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -581,6 +593,18 @@ class ZoneOperationsClient(metaclass=ZoneOperationsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.get]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("zone", request.zone),
+                    ("operation", request.operation),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -662,6 +686,17 @@ class ZoneOperationsClient(metaclass=ZoneOperationsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.list]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("zone", request.zone),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
@@ -782,6 +817,18 @@ class ZoneOperationsClient(metaclass=ZoneOperationsClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.wait]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project", request.project),
+                    ("zone", request.zone),
+                    ("operation", request.operation),
+                )
+            ),
+        )
+
         # Send the request.
         response = rpc(
             request,
