@@ -2018,6 +2018,28 @@ def test_region_instances_host_with_port(transport_name):
     )
 
 
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "rest",
+    ],
+)
+def test_region_instances_client_transport_session_collision(transport_name):
+    creds1 = ga_credentials.AnonymousCredentials()
+    creds2 = ga_credentials.AnonymousCredentials()
+    client1 = RegionInstancesClient(
+        credentials=creds1,
+        transport=transport_name,
+    )
+    client2 = RegionInstancesClient(
+        credentials=creds2,
+        transport=transport_name,
+    )
+    session1 = client1.transport.bulk_insert._session
+    session2 = client2.transport.bulk_insert._session
+    assert session1 != session2
+
+
 def test_common_billing_account_path():
     billing_account = "squid"
     expected = "billingAccounts/{billing_account}".format(
